pub fn get_book_snapshots_pattern(
instrument_id: InstrumentId,
interval_ms: NonZeroUsize,
) -> MStr<Pattern>Expand description
Returns the subscription pattern for periodic order book snapshots on instrument_id.
pub fn get_book_snapshots_pattern(
instrument_id: InstrumentId,
interval_ms: NonZeroUsize,
) -> MStr<Pattern>Returns the subscription pattern for periodic order book snapshots on instrument_id.